//+------------------------------------------------------------------+
//|                                                 MA-crossover.mq4 |
//|                   https://sites.google.com/site/100forexsystems/ |
//|           Please see the website for entry and exit descriptions |
//+------------------------------------------------------------------+
#property copyright "webbedmaster@gmail.com"
#property link      "https://sites.google.com/site/100forexsystems/home/simple-systems/double-moving-average-crossover"

extern int magicNumber = 1234;
extern double lots = 1;
extern int MAFastPeriod = 1;
extern int MASlowPeriod = 100;

int slippage = 3;
double stopLoss = 0;
double takeProfit = 0;
int ticket;
int counter;
bool openOrder;
bool buySignal;
bool sellSignal;

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
{
   return(0);
}
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
{
   return(0);
}
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
   openOrder = false;
   
   generateSignals();
   
   //check for open orders
   for(counter=0;counter<OrdersTotal();counter++)   
   {
      OrderSelect(counter, SELECT_BY_POS, MODE_TRADES);     
      if (OrderMagicNumber() == magicNumber)
      {
         openOrder = true;
         
         //check for closing signals
         if (OrderType() == OP_BUY && sellSignal)
         {
            closeBuyTrade();
            openOrder = false;
         }
         else if (OrderType() == OP_SELL && buySignal)
         {
            closeSellTrade();
            openOrder = false;
         }
      }
   }
            
   //There are no open orders. check for signals.
   if (!openOrder)
   {
      stopLoss = 0;

      if (buySignal)
         placeBuy();
      else if (sellSignal)
         placeSell();
   }
   return(0);
}
//+------------------------------------------------------------------+
//| place BUY trade                                                  |
//+------------------------------------------------------------------+
void placeBuy()
{
   RefreshRates();            
   ticket=OrderSend(Symbol(),OP_BUY,lots,Ask,slippage,stopLoss,takeProfit,"buy",magicNumber,0,Green);  
   if(ticket<0)
   {
      Print("BUY failed with error #",GetLastError()," at ",Ask);
      return;
   }
}
//+------------------------------------------------------------------+
//| place SELL trade                                                 |
//+------------------------------------------------------------------+
void placeSell()
{
   RefreshRates();            
   ticket=OrderSend(Symbol(),OP_SELL,lots,Bid,slippage,stopLoss,takeProfit,"sell",magicNumber,0,Red);  
   if(ticket<0)
   {
      Print("SELL failed with error #",GetLastError()," at ",Bid);
      return;
   }
}
//+------------------------------------------------------------------+
//| calculate the trailing stop for a BUY trade
//+------------------------------------------------------------------+
void closeBuyTrade()
{
      RefreshRates();
      OrderClose(OrderTicket(),OrderLots(),Bid,slippage,Green);     
}
//+------------------------------------------------------------------+
//| calculate the trailing stop for a SELL trade
//+------------------------------------------------------------------+
void closeSellTrade()
{
      RefreshRates();
      OrderClose(OrderTicket(),OrderLots(),Ask,slippage,Red);  
}
//+------------------------------------------------------------------+
//| generate a buy or sell signal upon MA cross over
//+------------------------------------------------------------------+
void generateSignals()
{
   double MacdFastPrevious1, MacdFastPrevious2;
   double MacdSlowPrevious1, MacdSlowPrevious2;   
   buySignal = false;
   sellSignal = false;
   
   MacdFastPrevious1=iMA(NULL,0,MAFastPeriod,0,MODE_SMA,PRICE_CLOSE,1);
   MacdFastPrevious2=iMA(NULL,0,MAFastPeriod,0,MODE_SMA,PRICE_CLOSE,2);
   MacdSlowPrevious1=iMA(NULL,0,MASlowPeriod,0,MODE_SMA,PRICE_CLOSE,1);
   MacdSlowPrevious2=iMA(NULL,0,MASlowPeriod,0,MODE_SMA,PRICE_CLOSE,2);
   
   //fast MA crosses over slow MA.
   if (MacdFastPrevious1 > MacdSlowPrevious1 &&
       MacdFastPrevious2 < MacdSlowPrevious2)
      buySignal = true;
   //fast MA crosses below slow MA.
   else if (MacdFastPrevious1 < MacdSlowPrevious1 &&
            MacdFastPrevious2 > MacdSlowPrevious2)
      sellSignal = true;
}